unit ftpermin;

{ set up typed constant arrays for storage of values of feet per minute of
latitude and longitude }

{ adapted by: Brandon C. Nuttall

              Kentucky Geological Survey
              228 Mining & Mineral Resources Building
              University of Kentucky
              Lexington, KY  40506-0107

  Language:   Borland International TURBO Pascal v4.0
  Computer:   DEC Rainbow PC 100B (512K)
  Operating system: MS-DOS v3.1

  Adapted from:
    FORTRAN version implemented by Kentucky Geological Survey in
    public domain.

**************************************************************************
*                                                                        *
*                            N O T I C E                                 *
*                                                                        *
*     This software is placed in the public domain by the Kentucky       *
*     Geological Survey and is supplied "as is".                         *
*                                                                        *
*     The Kentucky Geological Survey makes no warranty either express    *
*     or implied as to the accuracy or validity of these routines.  The  *
*     user assumes all liability for any losses or damages that may be   *
*     incurred through any use or application of this software.          *
*                                                                        *
**************************************************************************

NOTE: this unit uses "typed constants" available in TURBO Pascal.  This
may not be compatible with other Pascal compilers.

}

interface

const
  ccllnmin = 240; { size of feet per minute arrays }

type
  FPMArray = array[1..ccllnmin] of real;

const

  { feet on ground in 1 minute of longitude by minute of latitude }

  { NOTE: source of data is Special Publication 5 of the U.S. Coast and
    Geodetic Survey. }

  LonFtPerMin : FPMArray = (
          { 36d 0' } 4930.31,
          { 36d 1' } 4929.27,
          { 36d 2' } 4928.22,
          { 36d 3' } 4927.23,
          { 36d 4' } 4926.18,
          { 36d 5' } 4925.13,
          { 36d 6' } 4924.08,
          { 36d 7' } 4923.03,
          { 36d 8' } 4921.98,
          { 36d 9' } 4921.00,
          { 36d10' } 4919.95,
          { 36d11' } 4918.90,
          { 36d12' } 4917.85,
          { 36d13' } 4916.80,
          { 36d14' } 4915.75,
          { 36d15' } 4914.70,
          { 36d16' } 4913.65,
          { 36d17' } 4912.60,
          { 36d18' } 4911.55,
          { 36d19' } 4910.56,
          { 36d20' } 4909.51,
          { 36d21' } 4908.46,
          { 36d22' } 4907.41,
          { 36d23' } 4906.36,
          { 36d24' } 4905.31,
          { 36d25' } 4904.27,
          { 36d26' } 4903.22,
          { 36d27' } 4902.17,
          { 36d28' } 4901.12,
          { 36d29' } 4900.07,
          { 36d30' } 4899.02,
          { 36d31' } 4897.97,
          { 36d32' } 4896.92,
          { 36d33' } 4895.87,
          { 36d34' } 4894.82,
          { 36d35' } 4893.77,
          { 36d36' } 4892.72,
          { 36d37' } 4891.67,
          { 36d38' } 4890.62,
          { 36d39' } 4889.57,
          { 36d40' } 4888.52,
          { 36d41' } 4887.47,
          { 36d42' } 4886.35,
          { 36d43' } 4885.30,
          { 36d44' } 4884.25,
          { 36d45' } 4883.20,
          { 36d46' } 4882.15,
          { 36d47' } 4881.10,
          { 36d48' } 4880.05,
          { 36d49' } 4879.00,
          { 36d50' } 4877.95,
          { 36d51' } 4876.90,
          { 36d52' } 4875.79,
          { 36d53' } 4874.74,
          { 36d54' } 4873.69,
          { 36d55' } 4872.64,
          { 36d56' } 4871.59,
          { 36d57' } 4870.54,
          { 36d58' } 4869.42,
          { 36d59' } 4868.37,
          { 37d 0' } 4867.32,
          { 37d 1' } 4866.34,
          { 37d 2' } 4865.22,
          { 37d 3' } 4864.11,
          { 37d 4' } 4863.06,
          { 37d 5' } 4862.01,
          { 37d 6' } 4860.96,
          { 37d 7' } 4859.91,
          { 37d 8' } 4858.79,
          { 37d 9' } 4857.74,
          { 37d10' } 4856.69,
          { 37d11' } 4855.64,
          { 37d12' } 4854.53,
          { 37d13' } 4853.48,
          { 37d14' } 4852.43,
          { 37d15' } 4851.31,
          { 37d16' } 4850.26,
          { 37d17' } 4849.21,
          { 37d18' } 4848.16,
          { 37d19' } 4847.05,
          { 37d20' } 4846.00,
          { 37d21' } 4844.95,
          { 37d22' } 4843.83,
          { 37d23' } 4842.78,
          { 37d24' } 4841.73,
          { 37d25' } 4840.62,
          { 37d26' } 4839.57,
          { 37d27' } 4838.52,
          { 37d28' } 4837.40,
          { 37d29' } 4836.35,
          { 37d30' } 4835.30,
          { 37d31' } 4834.19,
          { 37d32' } 4833.14,
          { 37d33' } 4832.02,
          { 37d34' } 4830.97,
          { 37d35' } 4829.92,
          { 37d36' } 4828.81,
          { 37d37' } 4827.76,
          { 37d38' } 4826.64,
          { 37d39' } 4825.59,
          { 37d40' } 4824.54,
          { 37d41' } 4823.43,
          { 37d42' } 4822.38,
          { 37d43' } 4821.26,
          { 37d44' } 4820.21,
          { 37d45' } 4819.09,
          { 37d46' } 4818.04,
          { 37d47' } 4816.93,
          { 37d48' } 4815.88,
          { 37d49' } 4814.76,
          { 37d50' } 4813.71,
          { 37d51' } 4812.60,
          { 37d52' } 4811.55,
          { 37d53' } 4810.43,
          { 37d54' } 4809.38,
          { 37d55' } 4808.27,
          { 37d56' } 4807.22,
          { 37d57' } 4806.10,
          { 37d58' } 4805.05,
          { 37d59' } 4803.94,
          { 38d 0' } 4802.89,
          { 38d 1' } 4801.77,
          { 38d 2' } 4800.66,
          { 38d 3' } 4799.61,
          { 38d 4' } 4798.49,
          { 38d 5' } 4797.44,
          { 38d 6' } 4796.33,
          { 38d 7' } 4795.21,
          { 38d 8' } 4794.16,
          { 38d 9' } 4793.04,
          { 38d10' } 4791.99,
          { 38d11' } 4790.88,
          { 38d12' } 4789.76,
          { 38d13' } 4788.71,
          { 38d14' } 4787.60,
          { 38d15' } 4786.48,
          { 38d16' } 4785.43,
          { 38d17' } 4784.32,
          { 38d18' } 4783.20,
          { 38d19' } 4782.15,
          { 38d20' } 4781.04,
          { 38d21' } 4779.92,
          { 38d22' } 4778.81,
          { 38d23' } 4777.76,
          { 38d24' } 4776.64,
          { 38d25' } 4775.52,
          { 38d26' } 4774.48,
          { 38d27' } 4773.36,
          { 38d28' } 4772.24,
          { 38d29' } 4771.13,
          { 38d30' } 4770.08,
          { 38d31' } 4768.96,
          { 38d32' } 4767.85,
          { 38d33' } 4766.73,
          { 38d34' } 4765.68,
          { 38d35' } 4764.57,
          { 38d36' } 4763.45,
          { 38d37' } 4762.34,
          { 38d38' } 4761.22,
          { 38d39' } 4760.17,
          { 38d40' } 4759.06,
          { 38d41' } 4757.94,
          { 38d42' } 4756.82,
          { 38d43' } 4755.71,
          { 38d44' } 4754.66,
          { 38d45' } 4753.54,
          { 38d46' } 4752.43,
          { 38d47' } 4751.31,
          { 38d48' } 4750.20,
          { 38d49' } 4749.08,
          { 38d50' } 4748.03,
          { 38d51' } 4746.92,
          { 38d52' } 4745.80,
          { 38d53' } 4744.69,
          { 38d54' } 4743.57,
          { 38d55' } 4742.45,
          { 38d56' } 4741.34,
          { 38d57' } 4740.22,
          { 38d58' } 4739.11,
          { 38d59' } 4737.99,
          { 39d 0' } 4736.88,
          { 39d 1' } 4735.83,
          { 39d 2' } 4734.71,
          { 39d 3' } 4733.60,
          { 39d 4' } 4732.48,
          { 39d 5' } 4731.36,
          { 39d 6' } 4730.25,
          { 39d 7' } 4729.13,
          { 39d 8' } 4728.02,
          { 39d 9' } 4726.90,
          { 39d10' } 4725.79,
          { 39d11' } 4724.67,
          { 39d12' } 4723.56,
          { 39d13' } 4722.44,
          { 39d14' } 4721.33,
          { 39d15' } 4720.21,
          { 39d16' } 4719.09,
          { 39d17' } 4717.98,
          { 39d18' } 4716.86,
          { 39d19' } 4715.75,
          { 39d20' } 4714.63,
          { 39d21' } 4713.45,
          { 39d22' } 4712.34,
          { 39d23' } 4711.22,
          { 39d24' } 4710.10,
          { 39d25' } 4708.99,
          { 39d26' } 4707.87,
          { 39d27' } 4706.76,
          { 39d28' } 4705.64,
          { 39d29' } 4704.53,
          { 39d30' } 4703.41,
          { 39d31' } 4702.30,
          { 39d32' } 4701.12,
          { 39d33' } 4700.00,
          { 39d34' } 4698.88,
          { 39d35' } 4697.77,
          { 39d36' } 4696.65,
          { 39d37' } 4695.54,
          { 39d38' } 4694.36,
          { 39d39' } 4693.24,
          { 39d40' } 4692.13,
          { 39d41' } 4691.01,
          { 39d42' } 4689.90,
          { 39d43' } 4688.71,
          { 39d44' } 4687.60,
          { 39d45' } 4686.48,
          { 39d46' } 4685.37,
          { 39d47' } 4684.25,
          { 39d48' } 4683.07,
          { 39d49' } 4681.96,
          { 39d50' } 4680.84,
          { 39d51' } 4679.72,
          { 39d52' } 4678.54,
          { 39d53' } 4677.43,
          { 39d54' } 4676.31,
          { 39d55' } 4675.20,
          { 39d56' } 4674.02,
          { 39d57' } 4672.90,
          { 39d58' } 4671.78,
          { 39d59' } 4670.67);
	  
  { feet on ground in 1 minute of latitude by minute of latitude }
  LatFtPerMin : FPMArray = (
          { 36d 0' } 6067.13,
          { 36d 1' } 6067.13,
          { 36d 2' } 6067.13,
          { 36d 3' } 6067.13,
          { 36d 4' } 6067.32,
          { 36d 5' } 6067.32,
          { 36d 6' } 6067.32,
          { 36d 7' } 6067.32,
          { 36d 8' } 6067.32,
          { 36d 9' } 6067.32,
          { 36d10' } 6067.32,
          { 36d11' } 6067.32,
          { 36d12' } 6067.32,
          { 36d13' } 6067.32,
          { 36d14' } 6067.32,
          { 36d15' } 6067.32,
          { 36d16' } 6067.52,
          { 36d17' } 6067.52,
          { 36d18' } 6067.52,
          { 36d19' } 6067.52,
          { 36d20' } 6067.52,
          { 36d21' } 6067.52,
          { 36d22' } 6067.52,
          { 36d23' } 6067.52,
          { 36d24' } 6067.52,
          { 36d25' } 6067.52,
          { 36d26' } 6067.52,
          { 36d27' } 6067.72,
          { 36d28' } 6067.72,
          { 36d29' } 6067.72,
          { 36d30' } 6067.72,
          { 36d31' } 6067.72,
          { 36d32' } 6067.72,
          { 36d33' } 6067.72,
          { 36d34' } 6067.72,
          { 36d35' } 6067.72,
          { 36d36' } 6067.72,
          { 36d37' } 6067.72,
          { 36d38' } 6067.72,
          { 36d39' } 6067.91,
          { 36d40' } 6067.91,
          { 36d41' } 6067.91,
          { 36d42' } 6067.91,
          { 36d43' } 6067.91,
          { 36d44' } 6067.91,
          { 36d45' } 6067.91,
          { 36d46' } 6067.91,
          { 36d47' } 6067.91,
          { 36d48' } 6067.91,
          { 36d49' } 6067.91,
          { 36d50' } 6068.11,
          { 36d51' } 6068.11,
          { 36d52' } 6068.11,
          { 36d53' } 6068.11,
          { 36d54' } 6068.11,
          { 36d55' } 6068.11,
          { 36d56' } 6068.11,
          { 36d57' } 6068.11,
          { 36d58' } 6068.11,
          { 36d59' } 6068.11,
          { 37d 0' } 6068.11,
          { 37d 1' } 6068.11,
          { 37d 2' } 6068.31,
          { 37d 3' } 6068.31,
          { 37d 4' } 6068.31,
          { 37d 5' } 6068.31,
          { 37d 6' } 6068.31,
          { 37d 7' } 6068.31,
          { 37d 8' } 6068.31,
          { 37d 9' } 6068.31,
          { 37d10' } 6068.31,
          { 37d11' } 6068.31,
          { 37d12' } 6068.31,
          { 37d13' } 6068.50,
          { 37d14' } 6068.50,
          { 37d15' } 6068.50,
          { 37d16' } 6068.50,
          { 37d17' } 6068.50,
          { 37d18' } 6068.50,
          { 37d19' } 6068.50,
          { 37d20' } 6068.50,
          { 37d21' } 6068.50,
          { 37d22' } 6068.50,
          { 37d23' } 6068.50,
          { 37d24' } 6068.70,
          { 37d25' } 6068.70,
          { 37d26' } 6068.70,
          { 37d27' } 6068.70,
          { 37d28' } 6068.70,
          { 37d29' } 6068.70,
          { 37d30' } 6068.70,
          { 37d31' } 6068.70,
          { 37d32' } 6068.70,
          { 37d33' } 6068.70,
          { 37d34' } 6068.70,
          { 37d35' } 6068.70,
          { 37d36' } 6068.90,
          { 37d37' } 6068.90,
          { 37d38' } 6068.90,
          { 37d39' } 6068.90,
          { 37d40' } 6068.90,
          { 37d41' } 6068.90,
          { 37d42' } 6068.90,
          { 37d43' } 6068.90,
          { 37d44' } 6068.90,
          { 37d45' } 6068.90,
          { 37d46' } 6068.90,
          { 37d47' } 6069.09,
          { 37d48' } 6069.09,
          { 37d49' } 6069.09,
          { 37d50' } 6069.09,
          { 37d51' } 6069.09,
          { 37d52' } 6069.09,
          { 37d53' } 6069.09,
          { 37d54' } 6069.09,
          { 37d55' } 6069.09,
          { 37d56' } 6069.09,
          { 37d57' } 6069.09,
          { 37d58' } 6069.29,
          { 37d59' } 6069.29,
          { 38d 0' } 6069.29,
          { 38d 1' } 6069.29,
          { 38d 2' } 6069.29,
          { 38d 3' } 6069.29,
          { 38d 4' } 6069.29,
          { 38d 5' } 6069.29,
          { 38d 6' } 6069.29,
          { 38d 7' } 6069.29,
          { 38d 8' } 6069.29,
          { 38d 9' } 6069.29,
          { 38d10' } 6069.49,
          { 38d11' } 6069.49,
          { 38d12' } 6069.49,
          { 38d13' } 6069.49,
          { 38d14' } 6069.49,
          { 38d15' } 6069.49,
          { 38d16' } 6069.49,
          { 38d17' } 6069.49,
          { 38d18' } 6069.49,
          { 38d19' } 6069.49,
          { 38d20' } 6069.49,
          { 38d21' } 6069.69,
          { 38d22' } 6069.69,
          { 38d23' } 6069.69,
          { 38d24' } 6069.69,
          { 38d25' } 6069.69,
          { 38d26' } 6069.69,
          { 38d27' } 6069.69,
          { 38d28' } 6069.69,
          { 38d29' } 6069.69,
          { 38d30' } 6069.69,
          { 38d31' } 6069.69,
          { 38d32' } 6069.88,
          { 38d33' } 6069.88,
          { 38d34' } 6069.88,
          { 38d35' } 6069.88,
          { 38d36' } 6069.88,
          { 38d37' } 6069.88,
          { 38d38' } 6069.88,
          { 38d39' } 6069.88,
          { 38d40' } 6069.88,
          { 38d41' } 6069.88,
          { 38d42' } 6069.88,
          { 38d43' } 6070.08,
          { 38d44' } 6070.08,
          { 38d45' } 6070.08,
          { 38d46' } 6070.08,
          { 38d47' } 6070.08,
          { 38d48' } 6070.08,
          { 38d49' } 6070.08,
          { 38d50' } 6070.08,
          { 38d51' } 6070.08,
          { 38d52' } 6070.08,
          { 38d53' } 6070.08,
          { 38d54' } 6070.08,
          { 38d55' } 6070.28,
          { 38d56' } 6070.28,
          { 38d57' } 6070.28,
          { 38d58' } 6070.28,
          { 38d59' } 6070.28,
          { 39d 0' } 6070.28,
          { 39d 1' } 6070.28,
          { 39d 2' } 6070.28,
          { 39d 3' } 6070.28,
          { 39d 4' } 6070.28,
          { 39d 5' } 6070.28,
          { 39d 6' } 6070.47,
          { 39d 7' } 6070.47,
          { 39d 8' } 6070.47,
          { 39d 9' } 6070.47,
          { 39d10' } 6070.47,
          { 39d11' } 6070.47,
          { 39d12' } 6070.47,
          { 39d13' } 6070.47,
          { 39d14' } 6070.47,
          { 39d15' } 6070.47,
          { 39d16' } 6070.47,
          { 39d17' } 6070.67,
          { 39d18' } 6070.67,
          { 39d19' } 6070.67,
          { 39d20' } 6070.67,
          { 39d21' } 6070.67,
          { 39d22' } 6070.67,
          { 39d23' } 6070.67,
          { 39d24' } 6070.67,
          { 39d25' } 6070.67,
          { 39d26' } 6070.67,
          { 39d27' } 6070.67,
          { 39d28' } 6070.87,
          { 39d29' } 6070.87,
          { 39d30' } 6070.87,
          { 39d31' } 6070.87,
          { 39d32' } 6070.87,
          { 39d33' } 6070.87,
          { 39d34' } 6070.87,
          { 39d35' } 6070.87,
          { 39d36' } 6070.87,
          { 39d37' } 6070.87,
          { 39d38' } 6070.87,
          { 39d39' } 6071.06,
          { 39d40' } 6071.06,
          { 39d41' } 6071.06,
          { 39d42' } 6071.06,
          { 39d43' } 6071.06,
          { 39d44' } 6071.06,
          { 39d45' } 6071.06,
          { 39d46' } 6071.06,
          { 39d47' } 6071.06,
          { 39d48' } 6071.06,
          { 39d49' } 6071.06,
          { 39d50' } 6071.26,
          { 39d51' } 6071.26,
          { 39d52' } 6071.26,
          { 39d53' } 6071.26,
          { 39d54' } 6071.26,
          { 39d55' } 6071.26,
          { 39d56' } 6071.26,
          { 39d57' } 6071.26,
          { 39d58' } 6071.26,
          { 39d59' } 6071.26);
implementation
end.

